from django.apps import AppConfig


class DnoticiasAuthConfig(AppConfig):
    name = 'dnoticias_auth'
